function figs1n2=figs1And2%
%
% This function generates Figs. 1 and 2 as shown on pages 2217 and 2118 of Applied Optics
% Volume 48 in the paper "Design and characterization of thin multiple
% aperture infrared cameras," by Portnoy, Pitsianis, Sun, Brady, Gibbons,
% Silver, Te Kolste, Chen, Dillon and Prather (Applied Optics Vol. 48, No.
% 11) pp5115-2126 (2009)
%
% Figure 1 plots the pixel transfer function, optical transfer function and
% system transfer function (see chapter 7 of Brady, Optical Imaging and
% Spectroscopy for definitions) of a single aperture camera and a 3 by 3 multiple aperture array each 
% with pixel pitch equal to 2.5 times lambda f/# 
%
    function otF= otf( u )
        %optical transfer function for a circular aperutre
        %   See Brady, Optical Imaging and Spectroscopy, 2009 Eqn. 6.67
        otF=(2/pi)*real(acos(u)-u.*sqrt(1-u.^2));
    end
    function ptF = ptf(x) 
        %pixel transfer function
        % delta is the pixel pitch in units of lambda*f/#
        delta=2.5;
        ptF=abs(sin(pi*(delta*x+10^-9))./(pi*(delta*x+10^-9))); 
    end
    function stF=stf(u)
        %stf function
        stF=ptf(u).*otf(u);
    end
figure(1);set(gcf,'color','white');
u=linspace(0,.3,512);
subplot(2,1,1);
plot(u,ptf(u),':',u,otf(u),'--k',u,stf(u),'-k');
axis([0 .3 0 1]);line([.2,.2],[0,1]);
title('Conventional Camera');legend('PTF','OTF','STF','Location','SouthWest');
subplot(2,1,2);
plot(u,ptf(3*u),':',u,otf(3*u),'--k',u,stf(3*u),'-k');
axis([0 .3 0 1]);line([.2,.2],[0,1]);
title('3 by 3 Multiple Aperture Camera');legend('PTF','OTF','STF');
%
%
% Fig. 2 is a plot of the mean square error as expressed in Eqn. 4:
%
%
% epsilon(u,v)=Sf(u,v)/(1+|STF|^2 Sf(u,f)/(Sn(u,v)+|STF|^2 Sa(u,v))
%
% where Sf(u,v) is the power spectral density of the signal at spatial frequency
% u,v, Sn is the power spectral density of all detection noise sources
% (photon noise, read noise, thermal noise, etc.) and Sa is the power
% spectral density of the signal aliased into the passband. 
%
%
% we assume in Fig. 2 that Sf, Sa and Sn are constant wrt to u,v. One may,
% of course, assume a different model for these terms.
%
% we assume cylindrical symmetry and plot epsilon only along the u axis
%
% We consider aliasing only from the first band, effectively assuming that
% the signal vanishes for higher harmonics
%
figure(2);set(gcf,'color','white');
u=linspace(0,.2,512);
    function eMaeSa=emasa(u,sasn,sfsn)
        %ratio of error for multiple apertures vs single aperture as a
        %function of the ratio of the aliased signal level to the noise
        %level (sasn) and the signal power density to noise power density
        %(sfsn). We assume that both these values are independent of
        %spatial frequency
        eMaeSa=(1+sfsn*stf(u).^2./(1+stf(u+.2).^2*sasn))./(1+sfsn*stf(3*u).^2./(1+stf(3*(u+.2)).^2*sasn));
    end
semilogy(u,emasa(u,0,100),':k',u,emasa(u,10,100),'--k',u,emasa(u,100,100),'-k');
xlabel('u'); title('\epsilon_{MA}/\epsilon_{SA}');legend('S_a/S_n=0','S_a/S_n=10','S_a/S_n=100','Location','SouthEast');

end